package cn.com.infosec.asn1.cmp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import java.util.Enumeration;

public class KeyRecRepContent extends ASN1Encodable {
   private PKIStatusInfo status;
   private CMPCertificate newSigCert;
   private ASN1Sequence caCerts;
   private ASN1Sequence keyPairHist;

   private KeyRecRepContent(ASN1Sequence seq) {
      Enumeration seq1;
      this.status = PKIStatusInfo.getInstance((seq1 = seq.getObjects()).nextElement());

      while(seq1.hasMoreElements()) {
         ASN1TaggedObject var2;
         int var3;
         if ((var3 = (var2 = ASN1TaggedObject.getInstance(seq1.nextElement())).getTagNo()) != 0) {
            if (var3 != 1) {
               if (var3 != 2) {
                  throw new IllegalArgumentException("unknown tag number: " + var2.getTagNo());
               }

               this.keyPairHist = ASN1Sequence.getInstance(var2.getObject());
            } else {
               this.caCerts = ASN1Sequence.getInstance(var2.getObject());
            }
         } else {
            this.newSigCert = CMPCertificate.getInstance(var2.getObject());
         }
      }

   }

   public static KeyRecRepContent getInstance(Object o) {
      if (o instanceof KeyRecRepContent) {
         return (KeyRecRepContent)o;
      } else if (o instanceof ASN1Sequence) {
         return new KeyRecRepContent((ASN1Sequence)o);
      } else {
         throw new IllegalArgumentException("Invalid object: " + o.getClass().getName());
      }
   }

   private void addOptional(ASN1EncodableVector v, int tagNo, ASN1Encodable obj) {
      if (obj != null) {
         DERTaggedObject var4;
         var4 = new DERTaggedObject.<init>(true, tagNo, obj);
         v.add(var4);
      }

   }

   public PKIStatusInfo getStatus() {
      return this.status;
   }

   public CMPCertificate getNewSigCert() {
      return this.newSigCert;
   }

   public CMPCertificate[] getCaCerts() {
      ASN1Sequence var1;
      if ((var1 = this.caCerts) == null) {
         return null;
      } else {
         int var4;
         CMPCertificate[] var2 = new CMPCertificate[var4 = var1.size()];

         for(int var3 = 0; var3 != var4; ++var3) {
            var2[var3] = CMPCertificate.getInstance(this.caCerts.getObjectAt(var3));
         }

         return var2;
      }
   }

   public CertifiedKeyPair[] getKeyPairHist() {
      ASN1Sequence var1;
      if ((var1 = this.keyPairHist) == null) {
         return null;
      } else {
         int var4;
         CertifiedKeyPair[] var2 = new CertifiedKeyPair[var4 = var1.size()];

         for(int var3 = 0; var3 != var4; ++var3) {
            var2[var3] = CertifiedKeyPair.getInstance(this.keyPairHist.getObjectAt(var3));
         }

         return var2;
      }
   }

   public DERObject toASN1Object() {
      KeyRecRepContent var10000 = this;
      KeyRecRepContent var10001 = this;
      KeyRecRepContent var10002 = this;
      KeyRecRepContent var10003 = this;
      KeyRecRepContent var10004 = this;
      ASN1EncodableVector var1;
      ASN1EncodableVector var10006 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10006.add(this.status);
      CMPCertificate var2 = this.newSigCert;
      var10004.addOptional(var1, 0, var2);
      ASN1Sequence var3 = var10003.caCerts;
      var10002.addOptional(var1, 1, var3);
      var3 = var10001.keyPairHist;
      var10000.addOptional(var1, 2, var3);
      return new DERSequence(var1);
   }
}
